==> jaguar_session-0.7.0.tar.gz: lib/src/session_cookie.dart <==
part of jaguar_auth.session;

/// Cookie based session manager
///
/// Stores all session data on a Cookie
class CookieSession implements SessionManager {
  /// Name of the cookie on which session data is stored
  final String cookieName;

  CookieSession([this.cookieName = 'session']);

  /// Incoming session data parsed from the request
  final Map<String, String> _inValues = {};

  /// Outgoing session data that must be written to the response
  final Map<String, String> _outValues = {};

  /// Should the session be updated?
  bool _shouldUpdate = false;

  /// Returns a session value by given [key]
  String getInValue(String key) => _inValues[key];

  UnmodifiableMapView<String, String> get inValues =>
      new UnmodifiableMapView<String, String>(_inValues);

  UnmodifiableMapView<String, String> get outValues =>
      new UnmodifiableMapView<String, String>(_outValues);

  /// Creates a new session
  void createSession(Map<String, String> values) {
    _inValues.clear();
    _inValues.addAll(values);
    _outValues.clear();
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Update session info
  Future<Null> updateSession(Map<String, String> values) async {
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Clears the session
  Future<Null> deleteSession() async {
    _outValues.clear();
    _shouldUpdate = true;
  }

  /// Parses session from the given [request]
  Future<Null> parseRequest(Request request) async {
    for (Cookie cook in request.cookies) {
      if (cook.name == cookieName) {
        dynamic valueMap = _decode(cook.value);
        if (valueMap is Map<String, String>) {
          _inValues.addAll(valueMap);
        }
        break;
      }
    }
  }

  /// Updates [response] with session details
  Future<Response> writeResponse(Request request, Response resp) async {
    if (_shouldUpdate) {
      Cookie cook = new Cookie(cookieName, _encode());
      resp.cookies.add(cook);
    }
    return resp;
  }

  /// Validates the current session
  ///
  /// Must throw exception on validation failure
  Future<Null> validate() async {}

  String _encode() {
    String str = JSON.encode(_outValues);
    //TODO encrypt
    return const Base64Codec.urlSafe().encode(str.codeUnits);
  }

  dynamic _decode(String data) {
    String str =
        new String.fromCharCodes(const Base64Codec.urlSafe().decode(data));
    //TODO decrypt
    return JSON.decode(str);
  }
}

==> jaguar_session-0.9.1.tar.gz: lib/src/session_cookie.dart <==
part of jaguar_auth.session;

/// Cookie based session manager
///
/// Stores all session data on a Cookie
class CookieSession implements SessionManager {
  /// Name of the cookie on which session data is stored
  final String cookieName;

  CookieSession([this.cookieName = 'session']);

  /// Incoming session data parsed from the request
  final Map<String, String> _inValues = {};

  /// Outgoing session data that must be written to the response
  final Map<String, String> _outValues = {};

  /// Should the session be updated?
  bool _shouldUpdate = false;

  /// Returns a session value by given [key]
  String getInValue(String key) => _inValues[key];

  /// Get incoming session data
  UnmodifiableMapView<String, String> get inValues =>
      new UnmodifiableMapView<String, String>(_inValues);

  /// Get outgoing session data
  UnmodifiableMapView<String, String> get outValues =>
      new UnmodifiableMapView<String, String>(_outValues);

  /// Creates a new session
  void createSession(Map<String, String> values) {
    _inValues.clear();
    _inValues.addAll(values);
    _outValues.clear();
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Updates session info
  Future<Null> updateSession(Map<String, String> values) async {
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Clears the session
  Future<Null> deleteSession() async {
    _outValues.clear();
    _shouldUpdate = true;
  }

  /// Parses session from the given [request]
  Future<Null> parseRequest(Request request) async {
    for (Cookie cook in request.cookies) {
      if (cook.name == cookieName) {
        dynamic valueMap = _decode(cook.value);
        if (valueMap is Map<String, String>) {
          _inValues.addAll(valueMap);
        }
        break;
      }
    }
  }

  /// Writes [response] with session details
  Future<Response> writeResponse(Request request, Response resp) async {
    if (_shouldUpdate) {
      Cookie cook = new Cookie(cookieName, _encode());
      resp.cookies.add(cook);
    }
    return resp;
  }

  /// Validates the current session
  ///
  /// Must throw exception on validation failure
  Future<Null> validate() async {}

  String _encode() {
    String str = JSON.encode(_outValues);
    //TODO encrypt
    return const Base64Codec.urlSafe().encode(str.codeUnits);
  }

  dynamic _decode(String data) {
    String str =
        new String.fromCharCodes(const Base64Codec.urlSafe().decode(data));
    //TODO decrypt
    return JSON.decode(str);
  }
}
